@@ -121,8 +121,8 @@ def h1s(args):
         cmd = cmd + ' -hitLimit=%s' % hitLimit
     if autoLimit == True:
         cmd = cmd + ' -autoLimit'
-    if not scoreThreshold == 10:
-        cmd = cmd + ' -scoreThreshold=%s' % scoreThreshold
+    if scoreThreshold:
+        cmd = cmd + ' -scoreThreshold'
     if not scoreCutoff == 10:
         cmd = cmd + ' -scoreCutoff=%s' % scoreCutoff
     if not aligner == 'muscle':
@@ -161,7 +161,7 @@ def h1s(args):
         sys.exit('Problem running\n%s' % (cmd))
 
 def main():
-    version = '2.2.5'
+    version = '2.2.13'
     parser = argparse.ArgumentParser(description='You are running h1s version ' + str(version) + '.')
     parser.add_argument('--version', action='version', version=str(version))
     required = parser.add_argument_group('Required arguments')
@@ -236,7 +236,7 @@ def main():
     hamstr_options.add_argument('--autoLimit', help='Invoke a lagPhase analysis on the score distribution from the hmmer search. This will determine automatically a hit limit for each query. Note, it will be effective for both the core compilation and the final ortholog search',
                                 action='store_true', default=False)
     hamstr_options.add_argument('--scoreThreshold', help='Instead of setting an automatic hit limit, you can specify with this flag that only candidates with an hmm score no less than x percent of the hmm score of the best hit are further evaluated. Default: x = 10. You can change this cutoff with the option -scoreCutoff. Note, it will be effective for both the core compilation and the final ortholog search',
-                                action='store', default=10, type=int)
+                                action='store_true', default=False)
     hamstr_options.add_argument('--scoreCutoff', help='In combination with -scoreThreshold you can define the percent range of the hmms core of the best hit up to which a candidate of the hmmsearch will be subjected for further evaluation. Default: 10',
                                 action='store', default=10, type=int)
     hamstr_options.add_argument('--aligner', help='Choose between mafft-linsi or muscle for the multiple sequence alignment. DEFAULT: muscle',
