@@ -29,6 +29,17 @@ from tqdm import tqdm
 import h1s.h1s as h1sFn
 import shutil
 
+def getSortedFiles(directory):
+    list = os.listdir(directory)
+    pairs = []
+    for file in list:
+        location = os.path.join(directory, file)
+        if isfile(location):
+            size = os.path.getsize(location)
+            pairs.append((size, file))
+    pairs.sort(key=lambda s: s[0], reverse=True)
+    return([x[1] for x in pairs])
+
 def prepare(args, step):
     (seqFile, seqName, oneseqPath, refspec, minDist, maxDist, coreOrth,
     append, force, cleanup, group, blast, db,
@@ -60,52 +71,91 @@ def prepare(args, step):
     otherArgs = [cpu, hyperthread, debug, True]
     return(basicArgs, ioArgs, pathArgs, coreArgs, hamstrArgs, fasArgs, otherArgs, mute)
 
-def compileCore(options, seeds, inFol, cpu):
+def getSeedName(seedFile):
+    seqName = seedFile.split('.')[0]
+    seqName = re.sub('[\|\.]', '_', seqName)
+    return(seqName)
+
+def getIndividualRuntime(step, outpath, seeds):
+    logFile = outpath + '/runtime_core.txt'
+    searchTerm = 'Core set compilation finished in'
+    if step == 'ortho':
+        logFile = outpath + '/runtime_ortho.txt'
+        searchTerm = 'Ortholog search completed in'
+    log = open(logFile, "w")
+    for seed in seeds:
+        seqName = getSeedName(seed)
+        logFile = outpath + '/' + seqName + '/oneSeq.log'
+        if os.path.exists(logFile):
+            with open(logFile, 'r') as f:
+                for line in f:
+                    if searchTerm in line:
+                        runtime = line.split()[-2]
+                        log.write('%s\t%s\n' % (seqName, runtime))
+        else:
+            missing = open(outpath + '/missing.txt', 'a+')
+            missing.write(step + '\t' + seqName + '\n')
+    log.close()
+
+def compileCore(options, seeds, inFol, cpu, outpath):
     print('Starting compiling core orthologs...')
     start = time.time()
     coreCompilationJobs = []
     for seed in seeds:
         seqFile = [inFol + '/' + seed]
-        seqName = seed.split('.')[0]
-        seqName = [re.sub('[\|\.]', '_', seqName)]
-        (basicArgs, ioArgs, pathArgs, coreArgs, hamstrArgs, fasArgs, otherArgs, mute) = prepare(seqFile + seqName + options, 'core')
+        seqName = getSeedName(seed)
+        (basicArgs, ioArgs, pathArgs, coreArgs, hamstrArgs, fasArgs, otherArgs, mute) = prepare(seqFile + [seqName] + options, 'core')
         coreCompilationJobs.append([basicArgs, ioArgs, pathArgs, coreArgs, hamstrArgs, fasArgs, otherArgs, mute])
     pool = mp.Pool(cpu)
     coreOut = []
     for _ in tqdm(pool.imap_unordered(h1sFn.h1s, coreCompilationJobs), total=len(coreCompilationJobs)):
         coreOut.append(_)
     end = time.time()
-    print('==> Core compiling finished in ' + '{:5.3f}s'.format(end-start))
+    # read logs file to get runtime for individual seeds
+    getIndividualRuntime('core', outpath, seeds)
+    hmsCoreTime = '{:5.3f}'.format(end-start)
+    print('==> Core compiling finished in %s sec' % hmsCoreTime) #'{:5.3f}s'.format(end-start))
+    return(hmsCoreTime)
 
-def searchOrtho(options, seeds, inFol, cpu):
+def searchOrtho(options, seeds, inFol, cpu, outpath):
     print('Searching orthologs for...')
     start = time.time()
     coreCompilationJobs = []
     for seed in seeds:
         seqFile = [inFol + '/' + seed]
-        seqName = seed.split('.')[0]
-        seqName = [re.sub('[\|\.]', '_', seqName)]
-        (basicArgs, ioArgs, pathArgs, coreArgs, hamstrArgs, fasArgs, otherArgs, mute) = prepare(seqFile + seqName + options, 'ortholog')
+        seqName = getSeedName(seed)
+        (basicArgs, ioArgs, pathArgs, coreArgs, hamstrArgs, fasArgs, otherArgs, mute) = prepare(seqFile + [seqName] + options, 'ortholog')
         if mute == True:
             print(seed)
         else:
             print('\n##### ' + seed)
         h1sFn.h1s([basicArgs, ioArgs, pathArgs, coreArgs, hamstrArgs, fasArgs, otherArgs, mute])
     end = time.time()
-    print('==> Ortholog search finished in ' + '{:5.3f}s'.format(end-start))
+    # read logs file to get runtime for individual seeds
+    getIndividualRuntime('ortho', outpath, seeds)
+    hmsOrthoTime = '{:5.3f}'.format(end-start)
+    print('==> Ortholog search finished in %s sec' % hmsOrthoTime)
+    return(hmsOrthoTime)
 
 def joinOutputs(outpath, jobName, seeds, keep):
+    print('Joining single outputs...')
     finalFa = '%s/%s.extended.fa' % (outpath, jobName)
     Path(outpath+'/singleOutput').mkdir(parents=True, exist_ok=True)
     with open(finalFa,'wb') as wfd:
         for seed in seeds:
-            seqName = seed.split('.')[0]
-            seqName = re.sub('[\|\.]', '_', seqName)
-            with open(outpath + '/' + seqName + '/' + seqName + '.extended.fa','rb') as fd:
-                shutil.copyfileobj(fd, wfd)
-            shutil.move(outpath + '/' + seqName, outpath + '/singleOutput')
+            seqName = getSeedName(seed)
+            resultFile = '%s/%s/%s.extended.fa'  % (outpath, seqName, seqName)
+            if os.path.exists(resultFile):
+                with open(resultFile,'rb') as fd:
+                    shutil.copyfileobj(fd, wfd)
+                shutil.move(outpath + '/' + seqName, outpath + '/singleOutput')
+            else:
+                Path(outpath+'/missingOutput').mkdir(parents=True, exist_ok=True)
+                shutil.move(outpath + '/' + seqName, outpath + '/missingOutput')
+                os.remove(outpath + '/' + seqName + '.fa')
     if keep == True:
         try:
+            print('Compressing single outputs...')
             shutil.make_archive(outpath + '/' + jobName + '_singleOutput', 'gztar', outpath+'/singleOutput')
         except:
             shutil.make_archive(outpath + '/' + jobName + '_singleOutput', 'tar', outpath+'/singleOutput')
@@ -119,13 +169,16 @@ def calcFAS (outpath, extendedFa, weightpath, cpu):
     try:
         subprocess.call([fasCmd], shell = True)
         end = time.time()
-        shutil.rmtree(outpath + '/tmp')
-        print('==> FAS calculation finished in ' + '{:5.3f}s'.format(end-start))
+        if os.path.exists(outpath + '/tmp'):
+            shutil.rmtree(outpath + '/tmp')
+        fasTime = '{:5.3f}s'.format(end-start)
+        print('==> FAS calculation finished in %s sec' % fasTime)
+        return(fasTime)
     except:
         sys.exit('Problem running\n%s' % (fasCmd))
 
 def main():
-    version = '2.2.5'
+    version = '2.2.13'
     parser = argparse.ArgumentParser(description='You are running h1s version ' + str(version) + '.')
     parser.add_argument('--version', action='version', version=str(version))
     required = parser.add_argument_group('Required arguments')
@@ -201,7 +254,7 @@ def main():
     hamstr_options.add_argument('--autoLimit', help='Invoke a lagPhase analysis on the score distribution from the hmmer search. This will determine automatically a hit limit for each query. Note, it will be effective for both the core compilation and the final ortholog search',
                                 action='store_true', default=False)
     hamstr_options.add_argument('--scoreThreshold', help='Instead of setting an automatic hit limit, you can specify with this flag that only candidates with an hmm score no less than x percent of the hmm score of the best hit are further evaluated. Default: x = 10. You can change this cutoff with the option -scoreCutoff. Note, it will be effective for both the core compilation and the final ortholog search',
-                                action='store', default=10, type=int)
+                                action='store_true', default=False)
     hamstr_options.add_argument('--scoreCutoff', help='In combination with -scoreThreshold you can define the percent range of the hmms core of the best hit up to which a candidate of the hmmsearch will be subjected for further evaluation. Default: 10',
                                 action='store', default=10, type=int)
     hamstr_options.add_argument('--aligner', help='Choose between mafft-linsi or muscle for the multiple sequence alignment. DEFAULT: muscle',
@@ -341,38 +394,45 @@ def main():
                 cpu, hyperthread, debug, silent]
 
     ### START
+    hmsLog = open(outpath + '/' + jobName + '_log.txt', "w")
     h1sStart = time.time()
-    seeds = [f for f in listdir(inFol) if isfile(join(inFol, f))]
+    seeds = getSortedFiles(inFol)
     print('PID ' + str(os.getpid()))
+    hmsLog.write('PID ' + str(os.getpid()) + '\n')
 
     ### run core compilation
     if reuseCore == False:
-        compileCore(options, seeds, inFol, cpu)
+        hmsCoreTime = compileCore(options, seeds, inFol, cpu, outpath)
+        hmsLog.write('==> Core compilation finished in %s sec\n' % hmsCoreTime)
 
     ### do ortholog search
-    ### create list of search taxa
-    searchTaxa = ''
-    searchGroup = 'all'
-    if not group == '':
-        print('Creating list for search taxa...')
-        searchTaxa = '%s/searchTaxa.txt' % (outpath)
-        searchGroup = group
-        cmd = 'perl %s/bin/getSearchTaxa.pl -i %s -b %s -h %s -r %s -n %s -t %s/taxonomy -o %s' % (oneseqPath, searchpath, evalBlast, evalHmmer, evalRelaxfac, searchGroup, oneseqPath, searchTaxa)
-        try:
-            subprocess.call([cmd], shell = True)
-        except:
-            sys.exit('Problem running\n%s' % (cmd))
-    ### run ortholog search
     if coreOnly == False:
-        searchOrtho(options, seeds, inFol, cpu)
+        ### create list of search taxa
+        searchTaxa = ''
+        searchGroup = 'all'
+        if not group == '':
+            print('Creating list for search taxa...')
+            searchTaxa = '%s/searchTaxa.txt' % (outpath)
+            searchGroup = group
+            cmd = 'perl %s/bin/getSearchTaxa.pl -i %s -b %s -h %s -r %s -n %s -t %s/taxonomy -o %s' % (oneseqPath, searchpath, evalBlast, evalHmmer, evalRelaxfac, searchGroup, oneseqPath, searchTaxa)
+            try:
+                subprocess.call([cmd], shell = True)
+            except:
+                sys.exit('Problem running\n%s' % (cmd))
+        ### run ortholog search
+        hmsOrthoTime = searchOrtho(options, seeds, inFol, cpu, outpath)
+        hmsLog.write('==> Ortholog search finished in %s sec\n' % hmsOrthoTime)
         ### join output
         finalFa = joinOutputs(outpath, jobName, seeds, keep)
         ### calculate FAS scores
         if fasoff == False:
-            calcFAS(outpath, finalFa, weightpath, cpu)
+            fasTime = calcFAS(outpath, finalFa, weightpath, cpu)
+            hmsLog.write('==> FAS calculation finished in %s sec\n' % fasTime)
 
     h1sEnd = time.time()
-    print('==> h1s finished in ' + '{:5.3f}s'.format(h1sEnd-h1sStart))
+    print('==> hms finished in ' + '{:5.3f}s'.format(h1sEnd-h1sStart))
+    hmsLog.write('==> hms finished in ' + '{:5.3f}s'.format(h1sEnd-h1sStart))
+    hmsLog.close()
 
 if __name__ == '__main__':
     main()
